@@ -109,5 +109,26 @@ globalVariables(c(
   "dose_periods",
   "grpseq",
   "time_differential",
-  "temp_flag"
+  "temp_flag",
+  "tmp_obs_nr_filter_confirmation",
+  "tmp_obs_nr_filter_confirmation.join",
+  "tmp_obs_nr_var_conf_flag",
+  "AGE",
+  "SEX",
+  "SMOKEFL",
+  "DIABETFL",
+  "TRTHYPFL",
+  "ATOXGR",
+  "ATOXGRL",
+  "ATOXGRH",
+  "ATOXDSCL",
+  "ATOXDSCH",
+  "GRADE_CRITERIA_CODE",
+  "DIRECTION",
+  "SI_UNIT_CHECK",
+  "SI_UNIT_UPPER",
+  "VAR_CHECK",
+  "TERM",
+  "TERM_UPPER",
+  "atoxgr_criteria_ctcv4"
 ))
